'use strict';

const _ = require('lodash');
const moment = require('moment');

module.exports = class DateTimeUtils {
    static createTimestampsFromDates (dates) {
        return _.mapValues(dates, date => date ? moment(date).unix() : null);
    }

    static isWithin (expectedDate, amount, unit) {
        const earliestMoment = moment(expectedDate).subtract(amount, unit);
        const latestMoment = moment(expectedDate).add(amount, unit);

        return actualDate => moment(actualDate).isBetween(earliestMoment, latestMoment, 'ms', '[]');
    }

    static unixIsWithin (expectedDate, amount, unit) {
        return unixTimestamp => {
            const actualDate = moment(parseInt(unixTimestamp * 1000, 10));

            return DateTimeUtils.isWithin(expectedDate, amount, unit)(actualDate);
        };
    }
};
