/* eslint-disable
 func-names,
 func-style,
 max-nested-callbacks,
 no-undefined,
 prefer-arrow-callback,
 */
/* global describe, it */

'use strict';

const _ = require('lodash');
const appModulePath = require('app-module-path');
const assert = require('assert');
const moment = require('moment');

appModulePath.addPath('./');

const DateTimeUtils = require('lib/dateTimeUtils');

describe('DateTimeUtils', function () {
    describe('DateTimeUtils::createTimestampsFromDates', function () {
        it('should create timestamps properly', function () {
            const dateDate = moment('2013-02-08').toDate();
            const dateMoment = moment('2015-02-08');
            const dateTimestamp = moment('2014-02-08').valueOf();

            const {
                dateDate: dateDateUnix,
                dateMoment: dateMomentUnix,
                dateTimestamp: dateTimestampUnix,
            } = DateTimeUtils.createTimestampsFromDates({
                dateDate,
                dateMoment,
                dateTimestamp,
            });

            assert.strictEqual(dateDate.getTime() / 1000, dateDateUnix);
            assert.strictEqual(dateMoment.valueOf() / 1000, dateMomentUnix);
            assert.strictEqual(dateTimestamp / 1000, dateTimestampUnix);
        });
    });

    describe('DateTimeUtils::isWithin', function () {
        it('should succeed when the target is close enough (using dates)', function () {
            const expectedDate = moment('2015-02-08').toDate();
            const actualDate = moment(expectedDate).subtract(5, 'minutes').toDate();

            assert.strictEqual(true, DateTimeUtils.isWithin(expectedDate, 5, 'minutes')(actualDate));
        });

        it('should fail when the target is not close enough (using dates)', function () {
            const expectedDate = moment('2015-02-08').toDate();
            const actualDate = moment(expectedDate).subtract(1, 'hour').toDate();

            assert.strictEqual(false, DateTimeUtils.isWithin(expectedDate, 5, 'minutes')(actualDate));
        });

        it('should succeed when the target is close enough (using moments)', function () {
            const expectedDate = moment('2015-02-08');
            const actualDate = moment(expectedDate).subtract(1, 'year');

            assert.strictEqual(true, DateTimeUtils.isWithin(expectedDate, 2, 'years')(actualDate));
        });

        it('should fail when the target is not close enough (using moments)', function () {
            const expectedDate = moment('2015-02-08');
            const actualDate = moment(expectedDate).subtract(2.5, 'years');

            assert.strictEqual(false, DateTimeUtils.isWithin(expectedDate, 2, 'years')(actualDate));
        });

        it('should succeed when the target is close enough (using timestamps)', function () {
            const expectedDate = moment('2015-02-08').valueOf();
            const actualDate = moment(expectedDate).add(999, 'ms').valueOf();

            assert.strictEqual(true, DateTimeUtils.isWithin(expectedDate, 1, 'second')(actualDate));
        });

        it('should fail when the target is not close enough (using timestamps)', function () {
            const expectedDate = moment('2015-02-08').valueOf();
            const actualDate = moment(expectedDate).add(1001, 'ms').valueOf();

            assert.strictEqual(false, DateTimeUtils.isWithin(expectedDate, 1, 'second')(actualDate));
        });
    });

    describe('DateTimeUtils::unixIsWithin', function () {
        it('should succeed when the target is close enough', function () {
            const expectedDate = moment('2015-02-08').toDate();
            const actualDate = moment(expectedDate).subtract(5, 'minutes').unix();

            assert.strictEqual(true, DateTimeUtils.unixIsWithin(expectedDate, 5, 'minutes')(actualDate));
        });

        it('should fail when the target is not close enough', function () {
            const expectedDate = moment('2015-02-08').toDate();
            const actualDate = moment(expectedDate).subtract(1, 'hour').unix();

            assert.strictEqual(false, DateTimeUtils.unixIsWithin(expectedDate, 5, 'minutes')(actualDate));
        });
    });
});
